@@ -38,6 +38,7 @@ EXTENSIONS = {
     'cu': {'text', 'cuda'},
     'cuh': {'text', 'cuda'},
     'cxx': {'text', 'c++'},
+    'cylc': {'text', 'cylc'},
     'dart': {'text', 'dart'},
     'def': {'text', 'def'},
     'dll': {'binary'},
@@ -51,6 +52,10 @@ EXTENSIONS = {
     'erb': {'text', 'erb'},
     'exe': {'binary'},
     'eyaml': {'text', 'yaml'},
+    'f03': {'text', 'fortran'},
+    'f08': {'text', 'fortran'},
+    'f90': {'text', 'fortran'},
+    'f95': {'text', 'fortran'},
     'feature': {'text', 'gherkin'},
     'fish': {'text', 'fish'},
     'fits': {'binary', 'fits'},
@@ -96,10 +101,12 @@ EXTENSIONS = {
     'jenkinsfile': {'text', 'groovy', 'jenkins'},
     'jinja': {'text', 'jinja'},
     'jinja2': {'text', 'jinja'},
+    'jl': {'text', 'julia'},
     'jpeg': {'binary', 'image', 'jpeg'},
     'jpg': {'binary', 'image', 'jpeg'},
     'js': {'text', 'javascript'},
     'json': {'text', 'json'},
+    'jsonld': {'text', 'json', 'jsonld'},
     'jsonnet': {'text', 'jsonnet'},
     'json5': {'text', 'json5'},
     'jsx': {'text', 'jsx'},
@@ -171,6 +178,7 @@ EXTENSIONS = {
     'r': {'text', 'r'},
     'rake': {'text', 'ruby'},
     'rb': {'text', 'ruby'},
+    'resx': {'text', 'resx', 'xml'},
     'rng': {'text', 'xml', 'relax-ng'},
     'rs': {'text', 'rust'},
     'rst': {'text', 'rst'},
@@ -244,6 +252,7 @@ EXTENSIONS = {
     'xsd': {'text', 'xml', 'xsd'},
     'xsl': {'text', 'xml', 'xsl'},
     'yaml': {'text', 'yaml'},
+    'yamlld': {'text', 'yaml', 'yamlld'},
     'yang': {'text', 'yang'},
     'yin': {'text', 'xml', 'yin'},
     'yml': {'text', 'yaml'},
